## Yandex Search

using yandex.ru for web search.
allows for 10k searches per day with validated mobile number.

Notes:
- Yandex highlights matching terms, leading to extra whitespace from
    `' '.join`

### pyyaxml
- pyyaxml was using py2 and had even issues then

## TODO:
- functionality to deal with daily quota
- functionality to deal with request-per-second limit

## Documentation
search operators:
    https://yandex.com/support/search/how-to-search/search-operators.html
settings:
    https://xml.yandex.ru/settings.xml
docs:
    https://tech.yandex.ru/xml/doc/dg/concepts/restrictions-docpage/
    https://yandex.com/support/search/robots/search-api.html
